@@ -1,4 +1,4 @@
-from pydantic import SecretStr, PostgresDsn, Field
+from pydantic import SecretStr, PostgresDsn, Field, RedisDsn
 from pydantic_settings import BaseSettings, SettingsConfigDict
 
 
@@ -8,6 +8,13 @@ class CommonSettings(BaseSettings):
     logging_formatter: str = 'default'
 
 
+class ValkeySettings(BaseSettings):
+    model_config = SettingsConfigDict(env_prefix='VALKEY_')
+
+    dsn: RedisDsn | None = None
+    sentinel_dsn: RedisDsn | None = None
+
+
 class DBSettings(BaseSettings):
     model_config = SettingsConfigDict(env_prefix='DB_')
 
@@ -31,5 +38,6 @@ class S3Settings(BaseSettings):
 
 
 settings = CommonSettings()
+valkey_settings = ValkeySettings()
 db_settings = DBSettings()
 s3_settings = S3Settings()
